@@ -27,6 +27,7 @@
 PHENIX_HOME = 'PHENIX_HOME'
 PHENIXVERSIONFILENAME = './phenix_env.sh'
 PHENIXVERSION = '1.13' # plugin version
+PHENIXVERSION18 = '1.18' # september 2020
 
 #python used to run phenix scripts
 PHENIX_PYTHON = 'phenix.python '  # keep the ending space
@@ -45,6 +46,7 @@ VALIDATION_CRYOEM = 'validation_cryoem.py'
 EMRINGER = 'emringer.py'
 GETVERSION = 'phenix.version'
 DOCKINMAP = 'dock_in_map.py'
+SYMMETRY = 'map_symmetry.py'
 mapBinarytoDirectory ={
     REALSPACEREFINE : PHENIX_SCRIPT_PATH2,
     SUPERPOSE : PHENIX_SCRIPT_PATH2,
@@ -53,6 +55,7 @@ mapBinarytoDirectory ={
     VALIDATION_CRYOEM: PHENIX_SCRIPT_PATH2,
     EMRINGER : PHENIX_SCRIPT_PATH1,
     GETVERSION: PHENIX_GETVERSION_PATH,
-    DOCKINMAP: PHENIX_SCRIPT_PATH2
+    DOCKINMAP: PHENIX_SCRIPT_PATH2,
+    SYMMETRY: PHENIX_SCRIPT_PATH2
 }
 DISPLAY='display'
\ No newline at end of file
