@@ -23,7 +23,7 @@
 # ***************************************************************************/
 
 # protocol to test the different phenix methods with .pdb and .cif files
-
+from chimera.protocols import ChimeraProtOperate
 from pwem.protocols.protocol_import import (ProtImportPdb,
                                                     ProtImportVolumes)
 from pyworkflow import Config
@@ -33,7 +33,7 @@ from phenix.protocols.protocol_real_space_refine import (PhenixProtRunRSRefine,
 from phenix.protocols.protocol_molprobity import PhenixProtRunMolprobity
 from phenix.protocols.protocol_validation_cryoem import PhenixProtRunValidationCryoEM
 from pyworkflow.tests import *
-from phenix import Plugin, PHENIXVERSION
+from phenix import Plugin, PHENIXVERSION, PHENIXVERSION18
 import json
 from phenix.protocols.protocol_emringer import PhenixProtRunEMRinger
 from phenix.protocols.protocol_superpose_pdbs import PhenixProtRunSuperposePDBs
@@ -256,9 +256,23 @@ class TestPhenixPdbCif(TestImportData):
         # import CIF
         structure_hemo_cif = self._importStructHemoCIF()
 
+        # chimera operate to repair cif file
+        extraCommands = ""
+        extraCommands += "scipionwrite #2 " \
+                         "prefix repaired_CIF_ChimeraX_\n"
+        extraCommands += "exit\n"
+
+        args = {'extraCommands': extraCommands,
+                'pdbFileToBeRefined': structure_hemo_cif
+                }
+        protChimera = self.newProtocol(ChimeraProtOperate, **args)
+        protChimera.setObjLabel('chimera operate\n repairing CIF\n')
+        self.launchProtocol(protChimera)
+        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_000090
+
         # EMRinger
         args = {'inputVolume': volume_hemo_orig,
-                'inputStructure': structure_hemo_cif,
+                'inputStructure': result,
                 'doTest': True
                 }
         protEMRinger = self.newProtocol(PhenixProtRunEMRinger, **args)
@@ -365,7 +379,14 @@ class TestPhenixPdbCif(TestImportData):
                                       clashScore=2.43,
                                       overallScore=1.12,
                                       protRSRefine=protRSRefine)
-
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=96.64,
+                                      rotOutliers=4.77,
+                                      cbetaOutliers=0,
+                                      clashScore=6.07,
+                                      overallScore=2.06,
+                                      protRSRefine=protRSRefine)
         else:
             self.checkRSRefineResults(ramOutliers=0.00,
                                       ramFavored=96.11,
@@ -396,6 +417,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=2.43,
                                 overallScore=1.12,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkMPResults(ramOutliers=0.00,
+                                ramFavored=96.64,
+                                rotOutliers=4.77,
+                                cbetaOutliers=0,
+                                clashScore=6.07,
+                                overallScore=2.06,
+                                protMolProbity=protMolProbity2)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
@@ -458,11 +487,25 @@ class TestPhenixPdbCif(TestImportData):
         # import PDB
         structure_hemo_cif = self._importStructHemoCIF()
 
+        # chimera operate to repair cif file
+        extraCommands = ""
+        extraCommands += "scipionwrite #2 " \
+                         "prefix repaired_CIF_ChimeraX_\n"
+        extraCommands += "exit\n"
+
+        args = {'extraCommands': extraCommands,
+                'pdbFileToBeRefined': structure_hemo_cif
+                }
+        protChimera = self.newProtocol(ChimeraProtOperate, **args)
+        protChimera.setObjLabel('chimera operate\n repairing CIF\n')
+        self.launchProtocol(protChimera)
+        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_000772
+
         # MolProbity
         args = {
                 'inputVolume': volume_hemo_org,
                 'resolution': 3.2,
-                'inputStructure': structure_hemo_cif,
+                'inputStructure': result,
                 'numberOfThreads': 4
                 }
         protMolProbity = self.newProtocol(PhenixProtRunMolprobity, **args)
@@ -501,7 +544,14 @@ class TestPhenixPdbCif(TestImportData):
                                       clashScore=2.43,
                                       overallScore=1.12,
                                       protRSRefine=protRSRefine)
-
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=96.64,
+                                      rotOutliers=4.77,
+                                      cbetaOutliers=0,
+                                      clashScore=6.07,
+                                      overallScore=2.06,
+                                      protRSRefine=protRSRefine)
         else:
             # values obtained from phenix GUI v. 1.16
             # (minimization_global + adp)
@@ -534,6 +584,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=2.43,
                                 overallScore=1.12,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkMPResults(ramOutliers=0.00,
+                                ramFavored=96.64,
+                                rotOutliers=4.77,
+                                cbetaOutliers=0,
+                                clashScore=6.07,
+                                overallScore=2.06,
+                                protMolProbity=protMolProbity2)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
@@ -597,11 +655,25 @@ class TestPhenixPdbCif(TestImportData):
         # import cif
         structure_hemo_cif_PDB = self._importStructHemoFromDB()
 
+        # chimera operate to repair cif file
+        extraCommands = ""
+        extraCommands += "scipionwrite #2 " \
+                         "prefix repaired_CIF_ChimeraX_\n"
+        extraCommands += "exit\n"
+
+        args = {'extraCommands': extraCommands,
+                'pdbFileToBeRefined': structure_hemo_cif_PDB
+                }
+        protChimera = self.newProtocol(ChimeraProtOperate, **args)
+        protChimera.setObjLabel('chimera operate\n repairing CIF\n')
+        self.launchProtocol(protChimera)
+        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_001077
+
         # MolProbity
         args = {
                 'inputVolume': volume_hemo_org,
                 'resolution': 3.2,
-                'inputStructure': structure_hemo_cif_PDB,
+                'inputStructure': result,
                 'numberOfThreads': 4
                 }
         protMolProbity = self.newProtocol(PhenixProtRunMolprobity, **args)
@@ -641,6 +713,15 @@ class TestPhenixPdbCif(TestImportData):
                                       overallScore=1.12,
                                       protRSRefine=protRSRefine)
 
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=96.64,
+                                      rotOutliers=4.77,
+                                      cbetaOutliers=0,
+                                      clashScore=6.07,
+                                      overallScore=2.06,
+                                      protRSRefine=protRSRefine)
+
         else:
             # values obtained from phenix GUI v. 1.16
             # (minimization_global + adp)
@@ -673,6 +754,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=2.43,
                                 overallScore=1.12,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION18:
+            self.checkMPResults(ramOutliers=0.00,
+                                ramFavored=96.64,
+                                rotOutliers=4.77,
+                                cbetaOutliers=0,
+                                clashScore=6.07,
+                                overallScore=2.06,
+                                protMolProbity=protMolProbity2)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
