@@ -189,7 +189,6 @@ class TestValCryoEM(TestImportData):
                              protRSRefine, places=2, delta=3):
         # method to check Real Space Refine statistic results of the Final Results
         # Table
-        print("protRSRefine", protRSRefine.__dict__)
         try:
             self.assertAlmostEqual(protRSRefine.ramachandranFavored.get(),
                                    ramFavored, delta=delta)
@@ -595,12 +594,12 @@ class TestValCryoEM(TestImportData):
         protRSRefine.setObjLabel('RSRefine nucleosome\nvolume and '
                                  'pdb\n')
 
-        return
         # TODO, this protocol fails because
         # Opening quote in middle of word: ATOM 5963 O5' . DA I -72 ? 73.27900 73.22500 141.39500 1.000 212.95366 O ? L ? . 1
         # so 05' is not valid for the cif reader, I think is fair and should
         # not be counted as a problem
-        # self.launchProtocol(protRSRefine)
+        self.launchProtocol(protRSRefine) #Keep this line commented in pull requests
+        # return; self.launchProtocol(protRSRefine)
 
         # check real_space_refine results
         if Plugin.getPhenixVersion() == PHENIXVERSION:
